pub struct Session { /* private fields */ }Expand description
One port forward session that multiplexes many concurrent local connections over a pool of upgraded connections to the apiserver.
Implementations
Sourceimpl Session
impl Session
Sourcepub async fn connect(&self) -> Result<Stream, Error>
pub async fn connect(&self) -> Result<Stream, Error>
Grab the next stream and return a bidirectional Stream.
Sourcepub async fn replenish_spare_streams(&self)
pub async fn replenish_spare_streams(&self)
Pre open spare streams up to SPARE_STREAM_CAP.
pub fn spare_count(&self) -> usize
pub fn needs_replenish(&self) -> bool
pub const fn protocol(&self) -> Subprotocol
pub fn operating_capacity(&self) -> usize
pub fn in_use(&self) -> usize
pub fn available(&self) -> usize
pub fn is_full(&self) -> bool
pub fn is_drained(&self) -> bool
pub fn cancellation_token(&self) -> CancellationToken